( cd usr/lib64 ; rm -rf libclutter-gst-3.0.so )
( cd usr/lib64 ; ln -sf libclutter-gst-3.0.so.0.27.0 libclutter-gst-3.0.so )
( cd usr/lib64 ; rm -rf libclutter-gst-3.0.so.0 )
( cd usr/lib64 ; ln -sf libclutter-gst-3.0.so.0.27.0 libclutter-gst-3.0.so.0 )
